==> ignition_api_stubs-8.1.25.post1.tar.gz: ignition_api_stubs-8.1.25.post1/CHANGELOG.md <==
## v8.1.25.post1 (2023-02-21)

## v8.1.24.post1 (2023-02-21)

### Feat

- **java**: add GridLayout and JPasswordField (#99)
- **java**: add util.Arrays static class (#98)

## v8.1.25 (2023-02-15)

## v8.1.24.post1 (2023-02-21)

### Feat

- **java**: add GridLayout and JPasswordField (#99)
- **java**: add util.Arrays static class (#98)

## v8.1.25 (2023-02-15)

## v8.1.24 (2023-01-13)

### Feat

- **system**: add vision module (#85)

## v8.1.23 (2022-12-14)

### Fix

- create Number type alias (#78)

## v8.1.22.post1 (2022-11-30)

### Fix

- **ia**: use correct argument names (#75)

## v8.1.22 (2022-11-02)

## v8.1.21.post3 (2022-10-21)

### Fix

- change type hints on __iter__ methods (#69)

## v8.1.21.post2 (2022-10-19)

### Refactor

- improve type hints (#67)
- **ia**: add type hints to DatasetUtilities and WindowUtilities (#66)
- **ia**: add type hint to common.script.abc classes (#65)

## v8.1.21.post1 (2022-10-13)

### Feat

- **ia**: add classes implementing TagPath (#59)
- **ia**: add TagPathParser class (#58)

## v8.1.21 (2022-09-30)

### Feat

- **system**: add roster functions from 8.1.21 (#52)
- **system**: add util.getModules (#51)

## v8.1.20 (2022-09-22)

## v8.1.20b4 (2022-09-21)

### Feat

- **ia**: add LocaleUtils (#48)
- **java**: add java.text.SimpleDateFormat class (#47)

## v8.1.20b3 (2022-09-13)

### Feat

- **java**: add java.nio Files and Paths (#44)
- **java**: add type hints to all java[x] classes and methods (#40)

### Fix

- **system**: set smtp keyword argument as optional (#43)

## v8.1.20b2 (2022-08-30)

### Feat

- **ia**: add ApplicationScope class (#39)

## v8.1.20b1 (2022-08-26)

### Fix

- **system**: accept String arguments for popup position (#35)

## v8.1.20b0 (2022-08-26)

### Feat

- mirror ignition-api 2022-08-26 (#34)
- mirror ignition-api changes (#30)

### Fix

- **java**: add return value to getOutputStream (#27)

### Refactor

- **system**: change type for `tags` argument (#28)

## v8.1.19b4 (2022-08-05)

### Feat

- **ia**: add fields to SprocCall, SprocArg, and SProcArgKey (#24)

### Fix

- **system**: accept instances of Dataset (#23)

## v8.1.19b3 (2022-08-02)

### Fix

- **ia**: change the return type of dataset columns (#22)

### Refactor

- use java.lang.String for continuation/continuationPoint

## v8.1.19b2 (2022-08-02)

### Fix

- **system**: fix args and return type of tag.query (#21)

## v8.1.19b1 (2022-08-01)

### Fix

- **ia**: make class' properties accessible (#20)

## v8.1.19b0 (2022-07-29)

### Feat

- **system**: add new perspective and tag functions (#17)
- **system**: add constants to __all__ (#16)
- improve type hints (#15)

## v8.1.18a4 (2022-07-09)

## v8.1.18a3 (2022-07-05)

### Feat

- **ia**: implement all LoggerEx functions (#6)

### Fix

- **ci**: remove Python 3.11

## v8.1.18a2 (2022-06-29)

## v8.1.18a1 (2022-06-29)

### Fix

- mypy warnings (#1)
- mypy warnings

## v8.1.18a0 (2022-06-29)

==> ignition_api_stubs-8.1.26.tar.gz: ignition_api_stubs-8.1.26/CHANGELOG.md <==
## v8.1.26 (2023-03-26)

## v8.1.25.post5 (2023-03-20)

### Refactor

- **system**: replace BasicDataset with Dataset (#108)

## v8.1.25.post4 (2023-03-09)

### Feat

- **system**: add iec61850 module (#107)

## v8.1.25.post3 (2023-02-23)

## v8.1.24.post3 (2023-02-23)

### Fix

- **javax**: add return type to JPasswordField.getPassword (#103)

## v8.1.25.post2 (2023-02-23)

## v8.1.24.post2 (2023-02-23)

### Feat

- **javax**: add JPasswordField getText (#100)

### Refactor

- **java**: create the String class (#101)

## v8.1.25.post1 (2023-02-21)

## v8.1.24.post1 (2023-02-21)

### Feat

- **java**: add GridLayout and JPasswordField (#99)
- **java**: add util.Arrays static class (#98)

## v8.1.25.post5 (2023-03-20)

### Refactor

- **system**: replace BasicDataset with Dataset (#108)

## v8.1.25.post4 (2023-03-09)

### Feat

- **system**: add iec61850 module (#107)

## v8.1.25.post3 (2023-02-23)

## v8.1.24.post3 (2023-02-23)

### Fix

- **javax**: add return type to JPasswordField.getPassword (#103)

## v8.1.25.post2 (2023-02-23)

## v8.1.24.post2 (2023-02-23)

### Feat

- **javax**: add JPasswordField getText (#100)

### Refactor

- **java**: create the String class (#101)

## v8.1.25.post1 (2023-02-21)

## v8.1.24.post1 (2023-02-21)

### Feat

- **java**: add GridLayout and JPasswordField (#99)
- **java**: add util.Arrays static class (#98)

## v8.1.25.post4 (2023-03-09)

### Feat

- **system**: add iec61850 module (#107)

## v8.1.25.post3 (2023-02-23)

## v8.1.24.post3 (2023-02-23)

### Fix

- **javax**: add return type to JPasswordField.getPassword (#103)

## v8.1.25.post2 (2023-02-23)

## v8.1.24.post2 (2023-02-23)

### Feat

- **javax**: add JPasswordField getText (#100)

### Refactor

- **java**: create the String class (#101)

## v8.1.25.post1 (2023-02-21)

## v8.1.24.post1 (2023-02-21)

### Feat

- **java**: add GridLayout and JPasswordField (#99)
- **java**: add util.Arrays static class (#98)

## v8.1.25.post3 (2023-02-23)

## v8.1.24.post3 (2023-02-23)

### Fix

- **javax**: add return type to JPasswordField.getPassword (#103)

## v8.1.25.post2 (2023-02-23)

## v8.1.24.post2 (2023-02-23)

### Feat

- **javax**: add JPasswordField getText (#100)

### Refactor

- **java**: create the String class (#101)

## v8.1.25.post1 (2023-02-21)

## v8.1.24.post1 (2023-02-21)

### Feat

- **java**: add GridLayout and JPasswordField (#99)
- **java**: add util.Arrays static class (#98)

## v8.1.25 (2023-02-15)

## v8.1.24.post3 (2023-02-23)

### Fix

- **javax**: add return type to JPasswordField.getPassword (#103)

## v8.1.25.post2 (2023-02-23)

## v8.1.24.post2 (2023-02-23)

### Feat

- **javax**: add JPasswordField getText (#100)

### Refactor

- **java**: create the String class (#101)

## v8.1.25.post1 (2023-02-21)

## v8.1.24.post1 (2023-02-21)

### Feat

- **java**: add GridLayout and JPasswordField (#99)
- **java**: add util.Arrays static class (#98)

## v8.1.25.post2 (2023-02-23)

## v8.1.24.post2 (2023-02-23)

### Feat

- **javax**: add JPasswordField getText (#100)

### Refactor

- **java**: create the String class (#101)

## v8.1.25.post1 (2023-02-21)

## v8.1.24.post1 (2023-02-21)

### Feat

- **java**: add GridLayout and JPasswordField (#99)
- **java**: add util.Arrays static class (#98)

## v8.1.25 (2023-02-15)

## v8.1.24.post2 (2023-02-23)

### Feat

- **javax**: add JPasswordField getText (#100)

### Refactor

- **java**: create the String class (#101)

## v8.1.25.post1 (2023-02-21)

## v8.1.24.post1 (2023-02-21)

### Feat

- **java**: add GridLayout and JPasswordField (#99)
- **java**: add util.Arrays static class (#98)

## v8.1.25.post1 (2023-02-21)

## v8.1.24.post1 (2023-02-21)

### Feat

- **java**: add GridLayout and JPasswordField (#99)
- **java**: add util.Arrays static class (#98)

## v8.1.25 (2023-02-15)

## v8.1.24.post1 (2023-02-21)

### Feat

- **java**: add GridLayout and JPasswordField (#99)
- **java**: add util.Arrays static class (#98)

## v8.1.25 (2023-02-15)

## v8.1.24 (2023-01-13)

### Feat

- **system**: add vision module (#85)

## v8.1.23 (2022-12-14)

### Fix

- create Number type alias (#78)

## v8.1.22.post1 (2022-11-30)

### Fix

- **ia**: use correct argument names (#75)

## v8.1.22 (2022-11-02)

## v8.1.21.post3 (2022-10-21)

### Fix

- change type hints on __iter__ methods (#69)

## v8.1.21.post2 (2022-10-19)

### Refactor

- improve type hints (#67)
- **ia**: add type hints to DatasetUtilities and WindowUtilities (#66)
- **ia**: add type hint to common.script.abc classes (#65)

## v8.1.21.post1 (2022-10-13)

### Feat

- **ia**: add classes implementing TagPath (#59)
- **ia**: add TagPathParser class (#58)

## v8.1.21 (2022-09-30)

### Feat

- **system**: add roster functions from 8.1.21 (#52)
- **system**: add util.getModules (#51)

## v8.1.20 (2022-09-22)

## v8.1.20b4 (2022-09-21)

### Feat

- **ia**: add LocaleUtils (#48)
- **java**: add java.text.SimpleDateFormat class (#47)

## v8.1.20b3 (2022-09-13)

### Feat

- **java**: add java.nio Files and Paths (#44)
- **java**: add type hints to all java[x] classes and methods (#40)

### Fix

- **system**: set smtp keyword argument as optional (#43)

## v8.1.20b2 (2022-08-30)

### Feat

- **ia**: add ApplicationScope class (#39)

## v8.1.20b1 (2022-08-26)

### Fix

- **system**: accept String arguments for popup position (#35)

## v8.1.20b0 (2022-08-26)

### Feat

- mirror ignition-api 2022-08-26 (#34)
- mirror ignition-api changes (#30)

### Fix

- **java**: add return value to getOutputStream (#27)

### Refactor

- **system**: change type for `tags` argument (#28)

## v8.1.19b4 (2022-08-05)

### Feat

- **ia**: add fields to SprocCall, SprocArg, and SProcArgKey (#24)

### Fix

- **system**: accept instances of Dataset (#23)

## v8.1.19b3 (2022-08-02)

### Fix

- **ia**: change the return type of dataset columns (#22)

### Refactor

- use java.lang.String for continuation/continuationPoint

## v8.1.19b2 (2022-08-02)

### Fix

- **system**: fix args and return type of tag.query (#21)

## v8.1.19b1 (2022-08-01)

### Fix

- **ia**: make class' properties accessible (#20)

## v8.1.19b0 (2022-07-29)

### Feat

- **system**: add new perspective and tag functions (#17)
- **system**: add constants to __all__ (#16)
- improve type hints (#15)

## v8.1.18a4 (2022-07-09)

## v8.1.18a3 (2022-07-05)

### Feat

- **ia**: implement all LoggerEx functions (#6)

### Fix

- **ci**: remove Python 3.11

## v8.1.18a2 (2022-06-29)

## v8.1.18a1 (2022-06-29)

### Fix

- mypy warnings (#1)
- mypy warnings

## v8.1.18a0 (2022-06-29)
